==> apache-streampipes-0.95.0-source-release.zip: apache-streampipes-0.95.0/streampipes-rest/src/main/java/org/apache/streampipes/rest/impl/connect/UnitResource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.rest.impl.connect;

import org.apache.streampipes.commons.exceptions.connect.AdapterException;
import org.apache.streampipes.connect.management.management.UnitMasterManagement;
import org.apache.streampipes.model.connect.unit.UnitDescription;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/api/v2/connect/master/unit")
public class UnitResource extends AbstractAdapterResource<UnitMasterManagement> {

  private static final Logger logger = LoggerFactory.getLogger(UnitResource.class);

  public UnitResource() {
    super(UnitMasterManagement::new);
  }

  @PostMapping(
      consumes = MediaType.APPLICATION_JSON_VALUE,
      produces = MediaType.APPLICATION_JSON_VALUE
  )
  public ResponseEntity<?> getFittingUnits(@RequestBody UnitDescription unitDescription) {
    try {
      String resultingJson = managementService.getFittingUnits(unitDescription);
      return ok(resultingJson);
    } catch (AdapterException e) {
      logger.error("Error while getting all adapter descriptions", e);
      return fail();
    }
  }

}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-rest/src/main/java/org/apache/streampipes/rest/impl/connect/UnitResource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.rest.impl.connect;

import org.apache.streampipes.commons.exceptions.connect.AdapterException;
import org.apache.streampipes.connect.management.management.UnitMasterManagement;
import org.apache.streampipes.model.connect.unit.UnitDescription;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@RequestMapping("/api/v2/connect/master/unit")
public class UnitResource extends AbstractAdapterResource<UnitMasterManagement> {

  private static final Logger logger = LoggerFactory.getLogger(UnitResource.class);

  public UnitResource() {
    super(UnitMasterManagement::new);
  }

  @PostMapping(
      consumes = MediaType.APPLICATION_JSON_VALUE,
      produces = MediaType.APPLICATION_JSON_VALUE
  )
  @PreAuthorize("this.hasReadAuthority()")
  public ResponseEntity<?> getFittingUnits(@RequestBody UnitDescription unitDescription) {
    try {
      String resultingJson = managementService.getFittingUnits(unitDescription);
      return ok(resultingJson);
    } catch (AdapterException e) {
      logger.error("Error while getting all adapter descriptions", e);
      return fail();
    }
  }

  @GetMapping(path = "/units",
              produces = MediaType.APPLICATION_JSON_VALUE)
  @PreAuthorize("this.hasReadAuthority()")
  public ResponseEntity<List<UnitDescription>> getAllUnits() {
    List<UnitDescription> unitDescriptions = managementService.getAllUnitDescriptions();
    return ok(unitDescriptions);
  }

}
